@@ -747,10 +747,10 @@ class ShellUtil:
     @classmethod
     def exec(cls, conf: dict, cmd: str):
         cls._init(conf)
-        stdin, stdout, stderr = cls.CONN.exec_command(cmd, get_pty=True)
-        cls.CONN.close()
+        stdin, stdout, stderr = cls.CONN.exec_command(cmd)
         res = UniUtil.to_str(stdout.read())
         error = UniUtil.to_str(stderr.read())
+        cls.CONN.close()
         # 如果有错误信息，返回error，否则返回res
         if error.strip():
             return {'sta': 201, 'res': error}
@@ -825,15 +825,14 @@ class MinioUtil:
         return True
 
     @classmethod
-    def download(cls, conf: dict, bucket: str, filepath: str, filename: str):
+    def download(cls, conf: dict, bucket: str, dstfilepath: str, srcfilepath: str):
         """下载保存文件保存本地
-        :param bucket:
-        :param filepath:
-        :param filename:
-        :return:
+        :param bucket: 桶分区名称
+        :param dstfilepath: 下载后保存的本地路径
+        :param srcfilepath: minio桶分区下的路径
         """
         cls._init(conf)
-        cls.CONN.fget_object(bucket, filename, filepath)
+        cls.CONN.fget_object(bucket, dstfilepath, srcfilepath)
 
 
 class RedisUtil:
